import enum

class Code(enum.IntEnum):
    data = 0
    live = 1
    align = 2
    save = 3
    load = 4
    name = 5
    note = 6
    label = 7
    prolog = 8
    arg = 9
    addr = 10
    addi = 11
    addcr = 12
    addci = 13
    addxr = 14
    addxi = 15
    subr = 16
    subi = 17
    subcr = 18
    subci = 19
    subxr = 20
    subxi = 21
    rsbi = 22
    mulr = 23
    muli = 24
    qmulr = 25
    qmuli = 26
    qmulr_u = 27
    qmuli_u = 28
    divr = 29
    divi = 30
    divr_u = 31
    divi_u = 32
    qdivr = 33
    qdivi = 34
    qdivr_u = 35
    qdivi_u = 36
    remr = 37
    remi = 38
    remr_u = 39
    remi_u = 40
    andr = 41
    andi = 42
    orr = 43
    ori = 44
    xorr = 45
    xori = 46
    lshr = 47
    lshi = 48
    rshr = 49
    rshi = 50
    rshr_u = 51
    rshi_u = 52
    negr = 53
    comr = 54
    ltr = 55
    lti = 56
    ltr_u = 57
    lti_u = 58
    ler = 59
    lei = 60
    ler_u = 61
    lei_u = 62
    eqr = 63
    eqi = 64
    ger = 65
    gei = 66
    ger_u = 67
    gei_u = 68
    gtr = 69
    gti = 70
    gtr_u = 71
    gti_u = 72
    ner = 73
    nei = 74
    movr = 75
    movi = 76
    extr_c = 77
    extr_uc = 78
    extr_s = 79
    extr_us = 80
    extr_i = 81
    extr_ui = 82
    htonr_us = 83
    htonr_ui = 84
    htonr_ul = 85
    ldr_c = 86
    ldi_c = 87
    ldr_uc = 88
    ldi_uc = 89
    ldr_s = 90
    ldi_s = 91
    ldr_us = 92
    ldi_us = 93
    ldr_i = 94
    ldi_i = 95
    ldr_ui = 96
    ldi_ui = 97
    ldr_l = 98
    ldi_l = 99
    ldxr_c = 100
    ldxi_c = 101
    ldxr_uc = 102
    ldxi_uc = 103
    ldxr_s = 104
    ldxi_s = 105
    ldxr_us = 106
    ldxi_us = 107
    ldxr_i = 108
    ldxi_i = 109
    ldxr_ui = 110
    ldxi_ui = 111
    ldxr_l = 112
    ldxi_l = 113
    str_c = 114
    sti_c = 115
    str_s = 116
    sti_s = 117
    str_i = 118
    sti_i = 119
    str_l = 120
    sti_l = 121
    stxr_c = 122
    stxi_c = 123
    stxr_s = 124
    stxi_s = 125
    stxr_i = 126
    stxi_i = 127
    stxr_l = 128
    stxi_l = 129
    bltr = 130
    blti = 131
    bltr_u = 132
    blti_u = 133
    bler = 134
    blei = 135
    bler_u = 136
    blei_u = 137
    beqr = 138
    beqi = 139
    bger = 140
    bgei = 141
    bger_u = 142
    bgei_u = 143
    bgtr = 144
    bgti = 145
    bgtr_u = 146
    bgti_u = 147
    bner = 148
    bnei = 149
    bmsr = 150
    bmsi = 151
    bmcr = 152
    bmci = 153
    boaddr = 154
    boaddi = 155
    boaddr_u = 156
    boaddi_u = 157
    bxaddr = 158
    bxaddi = 159
    bxaddr_u = 160
    bxaddi_u = 161
    bosubr = 162
    bosubi = 163
    bosubr_u = 164
    bosubi_u = 165
    bxsubr = 166
    bxsubi = 167
    bxsubr_u = 168
    bxsubi_u = 169
    jmpr = 170
    jmpi = 171
    callr = 172
    calli = 173
    epilog = 174
    arg_f = 175
    addr_f = 176
    addi_f = 177
    subr_f = 178
    subi_f = 179
    rsbi_f = 180
    mulr_f = 181
    muli_f = 182
    divr_f = 183
    divi_f = 184
    negr_f = 185
    absr_f = 186
    sqrtr_f = 187
    ltr_f = 188
    lti_f = 189
    ler_f = 190
    lei_f = 191
    eqr_f = 192
    eqi_f = 193
    ger_f = 194
    gei_f = 195
    gtr_f = 196
    gti_f = 197
    ner_f = 198
    nei_f = 199
    unltr_f = 200
    unlti_f = 201
    unler_f = 202
    unlei_f = 203
    uneqr_f = 204
    uneqi_f = 205
    unger_f = 206
    ungei_f = 207
    ungtr_f = 208
    ungti_f = 209
    ltgtr_f = 210
    ltgti_f = 211
    ordr_f = 212
    ordi_f = 213
    unordr_f = 214
    unordi_f = 215
    truncr_f_i = 216
    truncr_f_l = 217
    extr_f = 218
    extr_d_f = 219
    movr_f = 220
    movi_f = 221
    ldr_f = 222
    ldi_f = 223
    ldxr_f = 224
    ldxi_f = 225
    str_f = 226
    sti_f = 227
    stxr_f = 228
    stxi_f = 229
    bltr_f = 230
    blti_f = 231
    bler_f = 232
    blei_f = 233
    beqr_f = 234
    beqi_f = 235
    bger_f = 236
    bgei_f = 237
    bgtr_f = 238
    bgti_f = 239
    bner_f = 240
    bnei_f = 241
    bunltr_f = 242
    bunlti_f = 243
    bunler_f = 244
    bunlei_f = 245
    buneqr_f = 246
    buneqi_f = 247
    bunger_f = 248
    bungei_f = 249
    bungtr_f = 250
    bungti_f = 251
    bltgtr_f = 252
    bltgti_f = 253
    bordr_f = 254
    bordi_f = 255
    bunordr_f = 256
    bunordi_f = 257
    arg_d = 258
    addr_d = 259
    addi_d = 260
    subr_d = 261
    subi_d = 262
    rsbi_d = 263
    mulr_d = 264
    muli_d = 265
    divr_d = 266
    divi_d = 267
    negr_d = 268
    absr_d = 269
    sqrtr_d = 270
    ltr_d = 271
    lti_d = 272
    ler_d = 273
    lei_d = 274
    eqr_d = 275
    eqi_d = 276
    ger_d = 277
    gei_d = 278
    gtr_d = 279
    gti_d = 280
    ner_d = 281
    nei_d = 282
    unltr_d = 283
    unlti_d = 284
    unler_d = 285
    unlei_d = 286
    uneqr_d = 287
    uneqi_d = 288
    unger_d = 289
    ungei_d = 290
    ungtr_d = 291
    ungti_d = 292
    ltgtr_d = 293
    ltgti_d = 294
    ordr_d = 295
    ordi_d = 296
    unordr_d = 297
    unordi_d = 298
    truncr_d_i = 299
    truncr_d_l = 300
    extr_d = 301
    extr_f_d = 302
    movr_d = 303
    movi_d = 304
    ldr_d = 305
    ldi_d = 306
    ldxr_d = 307
    ldxi_d = 308
    str_d = 309
    sti_d = 310
    stxr_d = 311
    stxi_d = 312
    bltr_d = 313
    blti_d = 314
    bler_d = 315
    blei_d = 316
    beqr_d = 317
    beqi_d = 318
    bger_d = 319
    bgei_d = 320
    bgtr_d = 321
    bgti_d = 322
    bner_d = 323
    bnei_d = 324
    bunltr_d = 325
    bunlti_d = 326
    bunler_d = 327
    bunlei_d = 328
    buneqr_d = 329
    buneqi_d = 330
    bunger_d = 331
    bungei_d = 332
    bungtr_d = 333
    bungti_d = 334
    bltgtr_d = 335
    bltgti_d = 336
    bordr_d = 337
    bordi_d = 338
    bunordr_d = 339
    bunordi_d = 340
    movr_w_f = 341
    movr_ww_d = 342
    movr_w_d = 343
    movr_f_w = 344
    movi_f_w = 345
    movr_d_ww = 346
    movi_d_ww = 347
    movr_d_w = 348
    movi_d_w = 349
    x86_retval_f = 350
    x86_retval_d = 351
